==> haskell-stmonadtrans-0.4.5-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 STMonadTrans
version:              0.4.5
visibility:           public
id:                   STMonadTrans-0.4.5-3oy7dMeHIAjC6RpPTAT3hs
key:                  STMonadTrans-0.4.5-3oy7dMeHIAjC6RpPTAT3hs
license:              BSD-3-Clause
maintainer:           josef.svenningsson@gmail.com
author:               Josef Svenningsson
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  cf3684cec2839ed75fc386e2091549e0
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-8.10.4/site-local/STMonadTrans-0.4.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/STMonadTrans-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/STMonadTrans-0.4.5
hs-libraries:         HSSTMonadTrans-0.4.5-3oy7dMeHIAjC6RpPTAT3hs
depends:              array-0.5.4.0 base-4.14.1.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.4.5-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 STMonadTrans
version:              0.4.5
visibility:           public
id:                   STMonadTrans-0.4.5-EwGGXT54uNBtWT2Jczuz8
key:                  STMonadTrans-0.4.5-EwGGXT54uNBtWT2Jczuz8
license:              BSD-3-Clause
maintainer:           josef.svenningsson@gmail.com
author:               Josef Svenningsson
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  309318a3c3f44da54cd92281b5ba1493
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-8.10.4/site-local/STMonadTrans-0.4.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/STMonadTrans-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/STMonadTrans-0.4.5
hs-libraries:         HSSTMonadTrans-0.4.5-EwGGXT54uNBtWT2Jczuz8
depends:              array-0.5.4.0 base-4.14.1.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
